@@ -3,7 +3,7 @@
 	/**
 	 * Manage databases within a server
 	 *
-	 * $Id: all_db.php,v 1.45.2.1 2007/05/28 17:21:55 ioguix Exp $
+	 * $Id: all_db.php,v 1.45.2.2 2007/07/09 14:55:21 xzilla Exp $
 	 */
 
 	// Include application functions
@@ -17,13 +17,13 @@
 	 */
 	function doAlter($confirm) {
 		global $data, $misc, $_reload_browser;
-		global $PHP_SELF, $lang;
+		global $lang;
 	
 		if ($confirm) {
 			$misc->printTrail('database');
 			$misc->printTitle($lang['stralter'], 'pg.database.alter');
 			
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"all_db.php\" method=\"post\">\n";
 			echo "<table>\n";
 			echo "<tr><th class=\"data left required\">{$lang['strname']}</th>\n";
 			echo "<td class=\"data1\">";
@@ -82,14 +82,14 @@
 	 */
 	function doDrop($confirm) {
 		global $data, $misc;
-		global $PHP_SELF, $lang, $_reload_drop_database;
+		global $lang, $_reload_drop_database;
 
 		if ($confirm) {
 			$misc->printTrail('database');
 			$misc->printTitle($lang['strdrop'], 'pg.database.drop');
 			
 			echo "<p>", sprintf($lang['strconfdropdatabase'], $misc->printVal($_REQUEST['dropdatabase'])), "</p>\n";	
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"all_db.php\" method=\"post\">\n";
 			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
 			echo $misc->form;
 			echo "<input type=\"hidden\" name=\"dropdatabase\" value=\"", htmlspecialchars($_REQUEST['dropdatabase']), "\" />\n";
@@ -113,7 +113,7 @@
 	 */
 	function doCreate($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		$misc->printTrail('server');
 		$misc->printTitle($lang['strcreatedatabase'], 'pg.database.create');
@@ -133,7 +133,7 @@
 		// Fetch all tablespaces from the database
 		if ($data->hasTablespaces()) $tablespaces = $data->getTablespaces();
 
-		echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+		echo "<form action=\"all_db.php\" method=\"post\">\n";
 		echo "<table>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strname']}</th>\n";
 		echo "\t\t<td class=\"data1\"><input name=\"formName\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"",
@@ -212,7 +212,7 @@
 	 */
 	function doExport($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		$misc->printTrail('server');
 		$misc->printTabs('server','export');
@@ -261,7 +261,7 @@
 	 */
 	function doDefault($msg = '') {
 		global $data, $conf, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		$misc->printTrail('server');
 		$misc->printTabs('server','databases');
@@ -308,7 +308,7 @@
 			),
 			'drop' => array(
 				'title' => $lang['strdrop'],
-				'url'   => "{$PHP_SELF}?action=confirm_drop&amp;subject=database&amp;{$misc->href}&amp;",
+				'url'   => "all_db.php?action=confirm_drop&amp;subject=database&amp;{$misc->href}&amp;",
 				'vars'  => array('dropdatabase' => 'datname'),
 			),
 			'privileges' => array(
@@ -320,7 +320,7 @@
 		if ($data->hasAlterDatabase() ) {
 			$actions['alter'] = array(
 				'title' => $lang['stralter'],
-				'url'   => "{$PHP_SELF}?action=confirm_alter&amp;subject=database&amp;{$misc->href}&amp;",
+				'url'   => "all_db.php?action=confirm_alter&amp;subject=database&amp;{$misc->href}&amp;",
 				'vars'  => array('alterdatabase' => 'datname')
 			);
 		}
@@ -331,7 +331,7 @@
 		
 		$misc->printTable($databases, $columns, $actions, $lang['strnodatabases']);
 
-		echo "<p><a class=\"navlink\" href=\"$PHP_SELF?action=create&amp;{$misc->href}\">{$lang['strcreatedatabase']}</a></p>\n";
+		echo "<p><a class=\"navlink\" href=\"all_db.php?action=create&amp;{$misc->href}\">{$lang['strcreatedatabase']}</a></p>\n";
 
 	}
 	
