@@ -4,7 +4,7 @@
  * A class that implements the DB interface for Postgres
  * Note: This class uses ADODB and returns RecordSets.
  *
- * $Id: Postgres73.php,v 1.154 2005/10/17 08:28:23 jollytoad Exp $
+ * $Id: Postgres73.php,v 1.160.2.2 2007/05/28 16:49:08 ioguix Exp $
  */
 
 // @@@ THOUGHT: What about inherits? ie. use of ONLY???
@@ -217,12 +217,47 @@ class Postgres73 extends Postgres72 {
 	 * @param $comment The new comment for this schema
 	 * @return 0 success
 	 */
-	function updateSchema($schemaname, $comment) {
+
+	function updateSchema($schemaname, $comment, $name) {
 		$this->fieldClean($schemaname);
+		$this->fieldClean($name);
 		$this->clean($comment);
-		return $this->setComment('SCHEMA', $schemaname, '', $comment);
+	
+		$status = $this->beginTransaction();
+		if ($status != 0) {
+			$this->rollbackTransaction();
+			return -1;
+		}
+
+		$status = $this->setComment('SCHEMA', $schemaname, '', $comment);
+		if ($status != 0) {
+			$this->rollbackTransaction();
+			return -1;
+		}
+
+		// Only if the name has changed
+		if ($name != $schemaname) {
+			$sql = "ALTER SCHEMA \"{$schemaname}\" RENAME TO \"{$name}\"";
+			$status = $this->execute($sql);
+			if ($status != 0) {
+				$this->rollbackTransaction();
+				return -1;
+			}
+		}
+
+		return $this->endTransaction();
 	}
 
+	/**
+	 * Returns the specified variable information.
+	 * @return the field 
+	 */
+	function getVariable($setting) {
+		$sql = "SHOW $setting";
+		
+		return $this->selectSet($sql);
+	}
+	
 	/**
 	 * Returns all available variable information.
 	 * @return A recordset
@@ -232,7 +267,7 @@ class Postgres73 extends Postgres72 {
 		
 		return $this->selectSet($sql);
 	}
-	
+
 	/**
 	 * Returns all available process information.
 	 * @param $database (optional) Find only connections to specified database
@@ -248,7 +283,27 @@ class Postgres73 extends Postgres72 {
 		
 		return $this->selectSet($sql);
 	}
-	
+
+	/**
+	 * Returns table locks information in the current database
+	 * @return A recordset
+	 */
+	function getLocks() {
+		global $conf;
+		
+		if (!$conf['show_system'])
+			$where = "AND pn.nspname NOT LIKE 'pg\\\\_%'";
+		else 
+			$where = "AND nspname !~ '^pg_t(emp_[0-9]+|oast)$'";
+
+		$sql = "SELECT pn.nspname, pc.relname AS tablename, pl.transaction, pl.pid, pl.mode, pl.granted
+		FROM pg_catalog.pg_locks pl, pg_catalog.pg_class pc, pg_catalog.pg_namespace pn
+		WHERE pl.relation = pc.oid AND pc.relnamespace=pn.oid {$where}
+		ORDER BY nspname,tablename";
+
+		return $this->selectSet($sql);
+	}
+
 	// Table functions
 
 	/**
@@ -602,6 +657,61 @@ class Postgres73 extends Postgres72 {
 
 	// Sequence functions
 
+	/** 
+	 * Resets a given sequence to min value of sequence
+	 * @param $sequence Sequence name
+	 * @return 0 success
+	 * @return -1 sequence not found
+	 */
+	function resetSequence($sequence) {
+		// Get the minimum value of the sequence
+		$seq = $this->getSequence($sequence);
+		if ($seq->recordCount() != 1) return -1;
+		$minvalue = $seq->f['min_value'];
+
+		/* This double-cleaning is deliberate */
+		$this->fieldClean($sequence);
+		$this->clean($sequence);
+		
+		$sql = "SELECT pg_catalog.SETVAL('\"{$sequence}\"', {$minvalue})";
+		
+		return $this->execute($sql);
+	}
+
+	/** 
+	 * Execute nextval on a given sequence
+	 * @param $sequence Sequence name
+	 * @return 0 success
+	 * @return -1 sequence not found
+	 */
+	function nextvalSequence($sequence) {
+		/* This double-cleaning is deliberate */
+		$this->fieldClean($sequence);
+		$this->clean($sequence);
+
+		$sql = "SELECT pg_catalog.NEXTVAL('\"{$sequence}\"')";
+		
+		return $this->execute($sql);
+	}
+
+	/** 
+	 * Execute setval on a given sequence
+	 * @param $sequence Sequence name
+	 * @param $nextvalue The next value
+	 * @return 0 success
+	 * @return -1 sequence not found
+	 */
+	function setvalSequence($sequence, $nextvalue) {
+		/* This double-cleaning is deliberate */
+		$this->fieldClean($sequence);
+		$this->clean($sequence);
+		$this->clean($nextvalue);
+
+		$sql = "SELECT pg_catalog.SETVAL('\"{$sequence}\"', '{$nextvalue}')";
+		
+		return $this->execute($sql);
+	}
+
 	/**
 	 * Returns all sequences in the current database
 	 * @return A recordset
@@ -905,11 +1015,11 @@ class Postgres73 extends Postgres72 {
 	 */
 	function getTypes($all = false, $tabletypes = false, $domains = false) {
 		if ($all)
-			$where = 'pg_catalog.pg_type_is_visible(t.oid)';
+			$where = '1 = 1';
 		else
 			$where = "n.nspname = '{$this->_schema}'";
 		// Never show system table types
-		$where2 = "AND c.relnamespace NOT IN (SELECT oid FROM pg_catalog.pg_namespace WHERE nspname LIKE 'pg\\\\_%')";
+		$where2 = "AND c.relnamespace NOT IN (SELECT oid FROM pg_catalog.pg_namespace WHERE nspname LIKE 'pg@_%' ESCAPE '@')";
 
 		// Create type filter
 		$tqry = "'c'";
@@ -1101,8 +1211,8 @@ class Postgres73 extends Postgres72 {
 		if (!is_array($tables)) return -1;
 
 		
-		$tables_list = "'{$tables[0]['schemaname']}'";
-		$schema_list = "'{$tables[0]['tablename']}'";
+		$tables_list = "'{$tables[0]['tablename']}'";
+		$schema_list = "'{$tables[0]['schemaname']}'";
 		$schema_tables_list = "'{$tables[0]['schemaname']}.{$tables[0]['tablename']}'";
 		for ($i = 1; $i < sizeof($tables); $i++) {
 			$tables_list .= ", '{$tables[$i]['tablename']}'";
@@ -1749,32 +1859,45 @@ class Postgres73 extends Postgres72 {
 	}
 
 	// Aggregate functions
+
+	/**
+	 * Gets all information for an aggregate
+	 * @param $name The name of the aggregate
+	 * @param $basetype The input data type of the aggregate
+	 * @return A recordset
+	 */
+	function getAggregate($name, $basetype) {
+		$this->fieldclean($name);
+		$this->fieldclean($basetype);
 	
+		$sql = "SELECT p.proname, CASE p.proargtypes[0] WHEN 'pg_catalog.\"any\"'::pg_catalog.regtype THEN NULL ELSE
+			   pg_catalog.format_type(p.proargtypes[0], NULL) END AS proargtypes, a.aggtransfn, 
+			   format_type(a.aggtranstype, NULL) AS aggstype, a.aggfinalfn, a.agginitval, a.aggsortop, u.usename, 
+			   pg_catalog.obj_description(p.oid, 'pg_proc') AS aggrcomment
+			   FROM pg_catalog.pg_proc p, pg_catalog.pg_namespace n, pg_catalog.pg_user u, pg_catalog.pg_aggregate a 
+			   WHERE n.oid = p.pronamespace AND p.proowner=u.usesysid AND p.oid=a.aggfnoid 
+			   AND p.proisagg AND n.nspname='{$this->_schema}' 
+			   AND p.proname='" . $name . "' AND CASE p.proargtypes[0] WHEN 'pg_catalog.\"any\"'::pg_catalog.regtype 
+			   THEN NULL ELSE pg_catalog.format_type(p.proargtypes[0], NULL) END ='" . $basetype . "'";
+
+		return $this->selectSet($sql);
+	}
+
 	/**
 	 * Gets all aggregates
 	 * @return A recordset
 	 */
 	function getAggregates() {
-		$sql = "
-			SELECT
-				p.proname,
-				CASE p.proargtypes[0]
-					WHEN 'pg_catalog.\"any\"'::pg_catalog.regtype
-					THEN NULL
-					ELSE pg_catalog.format_type(p.proargtypes[0], NULL)
-				END AS proargtypes,
-				pg_catalog.obj_description(p.oid, 'pg_proc') AS aggcomment
-			FROM pg_catalog.pg_proc p
-				LEFT JOIN pg_catalog.pg_namespace n ON n.oid = p.pronamespace
-			WHERE
-				p.proisagg
-				AND n.nspname='{$this->_schema}'
-			ORDER BY 1, 2
-		";
+		$sql = "SELECT p.proname, CASE p.proargtypes[0] WHEN 'pg_catalog.\"any\"'::pg_catalog.regtype THEN NULL ELSE
+			   pg_catalog.format_type(p.proargtypes[0], NULL) END AS proargtypes, a.aggtransfn, u.usename, 
+			   pg_catalog.obj_description(p.oid, 'pg_proc') AS aggrcomment
+			   FROM pg_catalog.pg_proc p, pg_catalog.pg_namespace n, pg_catalog.pg_user u, pg_catalog.pg_aggregate a 
+			   WHERE n.oid = p.pronamespace AND p.proowner=u.usesysid AND p.oid=a.aggfnoid 
+			   AND p.proisagg AND n.nspname='{$this->_schema}' ORDER BY 1, 2";
 
 		return $this->selectSet($sql);
 	}
-	
+
 	// Operator Class functions
 	
 	/**
@@ -1833,7 +1956,8 @@ class Postgres73 extends Postgres72 {
 	function hasUserAndDbVariables() { return true; }
 	function hasCompositeTypes() { return true; }	
 	function hasFuncPrivs() { return true; }
-
+	function hasLocksView() { return true; }
+	
 }
 
 ?>
