@@ -3,7 +3,7 @@
 /**
  * A class that implements the Slony 1.0.x support plugin
  *
- * $Id: Slony.php,v 1.8.2.1 2005/11/16 08:02:28 chriskl Exp $
+ * $Id: Slony.php,v 1.12 2006/10/01 23:42:18 xzilla Exp $
  */
 
 include_once('./classes/plugins/Plugin.php');
@@ -45,13 +45,16 @@ class Slony extends Plugin {
 		// it's in.  We put an order by and limit 1 in here to guarantee
 		// only finding the first one, even if there are somehow two
 		// Slony schemas.
-		$sql = "SELECT pn.nspname AS schema, pu.usename AS owner, SUBSTRING(pn.nspname FROM 2) AS cluster,
-					pg_catalog.obj_description(pn.oid, 'pg_namespace') AS nspcomment
-					FROM pg_catalog.pg_proc pp, pg_catalog.pg_namespace pn, pg_catalog.pg_user pu
+		$sql = "SELECT pn.nspname AS schema, pu.usename AS owner, 
+                    SUBSTRING(pn.nspname FROM 2) AS cluster,
+                    pg_catalog.obj_description(pn.oid, 'pg_namespace') AS 
+                    nspcomment
+                    FROM pg_catalog.pg_proc pp, pg_catalog.pg_namespace pn, 
+                    pg_catalog.pg_user pu 
 					WHERE pp.pronamespace=pn.oid
 					AND pn.nspowner = pu.usesysid
 					AND pp.proname='slonyversion'
-					AND pn.nspname LIKE '\\\\_%' 
+					AND pn.nspname LIKE '@_%' ESCAPE '@'  
 					ORDER BY pn.nspname LIMIT 1";
 		$rs = $data->selectSet($sql);
 		if ($rs->recordCount() == 1) {
@@ -277,8 +280,15 @@ class Slony extends Plugin {
 		$schema = $this->slony_schema;
 		$data->fieldClean($schema);
 		
-		$sql = "SELECT * FROM \"{$schema}\".sl_node ORDER BY no_comment";
-		
+		// We use 10 seconds as the default check time since that is the
+		// the default in Slony, and it gives no mechanism to look it up
+		$sql = "SELECT no_id, no_active, no_comment, no_spool, ".
+				"CASE WHEN st_lag_time > '10 seconds'::interval ". 
+				"THEN 'outofsync' ELSE 'insync' END AS no_status ".
+				"FROM \"{$schema}\".sl_node ".
+				"LEFT JOIN \"{$schema}\".sl_status ON (no_id =st_received) ".
+				"ORDER BY no_comment";
+
 		return $data->selectSet($sql);
 	}
 
@@ -598,6 +608,32 @@ class Slony extends Plugin {
 		return $data->execute($sql);
 	}		
 
+    /**
+     * Return all tables we are not current in a replication set
+     */
+    function getNonRepTables()
+    {
+		global $data;
+        /*
+         * we cannot just query pg_tables as we want the OID of the table 
+         * for the subquery against the slony table. We could match on
+         * on schema name and table name, but the slony info isn't updated
+         * if the user renames a table which is in a replication set
+         */
+        $sql = "SELECT c.relname, n.nspname, n.nspname||'.'||c.relname AS qualname, 
+                    pg_get_userbyid(c.relowner) AS relowner
+                    FROM pg_class c
+                    LEFT JOIN pg_namespace n ON n.oid = c.relnamespace
+                    WHERE c.relkind = 'r' AND n.nspname NOT IN ('pg_catalog', 
+                    'information_schema', 'pg_toast') AND
+                    NOT(n.nspname = '_{$this->slony_cluster}' AND
+                    relname LIKE 'sl_%') AND 
+                    NOT EXISTS(SELECT 1 FROM _{$this->slony_cluster}.sl_table s
+                    WHERE s.tab_reloid = c.oid)
+                    ORDER BY n.nspname, c.relname";
+        return $data->selectSet($sql);
+    }
+
 	// SEQUENCES
 	
 	/**
