@@ -3,7 +3,7 @@
 	/**
 	 * Login screen
 	 *
-	 * $Id: login.php,v 1.32.2.1 2007/05/28 17:21:56 ioguix Exp $
+	 * $Id: login.php,v 1.32.2.2 2007/07/09 14:55:22 xzilla Exp $
 	 */
 	global $conf;
 	
@@ -11,8 +11,6 @@
 	// Check to see if the configuration file exists, if not, explain
 	require_once('./libraries/lib.inc.php');
 
-	global $PHP_SELF;
-
 	$misc->printHeader($lang['strlogin']);
 	$misc->printBody();
 	$misc->printTrail('root');
@@ -24,7 +22,7 @@
 	if (isset($msg)) $misc->printMsg($msg);
 ?>
 
-<form action="<?php echo $PHP_SELF ?>" method="post" name="login_form">
+<form action="" method="post" name="login_form">
 <?php
 	if (!empty($_POST)) $vars =& $_POST;
 	else $vars =& $_GET;
