@@ -3,7 +3,7 @@
 	/**
 	 * List tables in a database
 	 *
-	 * $Id: tblproperties.php,v 1.72.2.1 2007/05/28 17:21:56 ioguix Exp $
+	 * $Id: tblproperties.php,v 1.72.2.3 2007/07/11 07:59:27 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -43,7 +43,7 @@
 	 */
 	function doAlter($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		$misc->printTrail('table');
 		$misc->printTitle($lang['stralter'], 'pg.table.alter');
@@ -63,7 +63,7 @@
 			if (!isset($_POST['comment'])) $_POST['comment'] = $table->f['relcomment'];
 			if ($data->hasTablespaces() && !isset($_POST['tablespace'])) $_POST['tablespace'] = $table->f['tablespace'];
 			
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"tblproperties.php\" method=\"post\">\n";
 			echo "<table>\n";
 			echo "<tr><th class=\"data left required\">{$lang['strname']}</th>\n";
 			echo "<td class=\"data1\">";
@@ -117,7 +117,7 @@
 	
 	function doExport($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		// Determine whether or not the table has an object ID
 		$hasID = $data->hasObjectID($_REQUEST['table']);
@@ -175,7 +175,7 @@
 	
 	function doImport($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		$misc->printTrail('table');
 		$misc->printTabs('table','import');
@@ -222,7 +222,7 @@
 	 */
 	function doAddColumn($msg = '') {
 		global $data, $misc, $_reload_browser;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		if (!isset($_REQUEST['stage'])) $_REQUEST['stage'] = 1;
 
@@ -246,7 +246,7 @@
 				$misc->printTitle($lang['straddcolumn'], 'pg.column.add');
 				$misc->printMsg($msg);
 				echo "<script src=\"tables.js\" type=\"text/javascript\"></script>";
-				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+				echo "<form action=\"tblproperties.php\" method=\"post\">\n";
 
 				// Output table header
 				echo "<table>\n";
@@ -345,7 +345,7 @@
 	 */
 	function doProperties($msg = '') {
 		global $data, $misc, $_reload_browser;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		if (!isset($_REQUEST['stage'])) $_REQUEST['stage'] = 1;
 
@@ -358,7 +358,7 @@
 				$misc->printMsg($msg);
 				echo "<script src=\"tables.js\" type=\"text/javascript\"></script>";
 
-				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+				echo "<form action=\"tblproperties.php\" method=\"post\">\n";
 
 				// Output table header
 				echo "<table>\n";
@@ -407,6 +407,7 @@
 					htmlspecialchars($_REQUEST['field']), "\" /></td>";
 					
 				// Column type
+				$escaped_predef_types = array(); // the JS escaped array elements
 				if ($data->hasAlterColumnType()) {
 					// Fetch all available types
 					$types = $data->getTypes(true, false, true);
@@ -435,7 +436,6 @@
 					echo "<option value=\"[]\"", ($_REQUEST['array'] == '[]') ? ' selected="selected"' : '', ">[ ]</option>\n";
 					echo "</select>";
 					$predefined_size_types = array_intersect($data->predefined_size_types,array_keys($types_for_js));
-					$escaped_predef_types = array(); // the JS escaped array elements
 					foreach($predefined_size_types as $value) {
 						$escaped_predef_types[] = "'{$value}'";
 					}
@@ -513,7 +513,7 @@
 	 */
 	function doDrop($confirm) {
 		global $data, $database, $misc, $_reload_browser;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		if ($confirm) {
 			$misc->printTrail('column');
@@ -523,7 +523,7 @@
                     $misc->printVal($_REQUEST['table'])), "</p>\n";
 								
 
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"tblproperties.php\" method=\"post\">\n";
 			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
 			echo "<input type=\"hidden\" name=\"table\" value=\"", htmlspecialchars($_REQUEST['table']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"column\" value=\"", htmlspecialchars($_REQUEST['column']), "\" />\n";
@@ -593,7 +593,7 @@
 	 */
 	function doDefault($msg = '') {
 		global $data, $conf, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		function attPre(&$rowdata) {
 			global $data;
@@ -640,7 +640,7 @@
 				'field' => 'comment',
 			),
 		);
-		
+
 		$actions = array(
 			'properties' => array(
 				'title' => $lang['strproperties'],
@@ -649,20 +649,20 @@
 			),
 			'alter' => array(
 				'title' => $lang['stralter'],
-				'url'   => "{$PHP_SELF}?action=properties&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
+				'url'   => "tblproperties.php?action=properties&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
 				'vars'  => array('column' => 'attname'),
 			),
 			'drop' => array(
 				'title' => $lang['strdrop'],
-				'url'   => "{$PHP_SELF}?action=confirm_drop&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
+				'url'   => "tblproperties.php?action=confirm_drop&amp;{$misc->href}&amp;table=".urlencode($_REQUEST['table'])."&amp;",
 				'vars'  => array('column' => 'attname'),
 			),
 		);
-		
+
 		if (!$data->hasDropColumn()) unset($actions['drop']);
-		
+
 		$misc->printTable($attrs, $columns, $actions, null, 'attPre');
-		
+
 		echo "<br />\n";
 
 		echo "<ul>\n";
@@ -673,8 +673,8 @@
 		echo "\t<li><a href=\"tables.php?action=confinsertrow&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strinsert']}</a></li>\n";
 		echo "\t<li><a href=\"tables.php?action=confirm_empty&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strempty']}</a></li>\n";
 		echo "\t<li><a href=\"tables.php?action=confirm_drop&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['strdrop']}</a></li>\n";
-		echo "\t<li><a href=\"{$PHP_SELF}?action=add_column&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['straddcolumn']}</a></li>\n";
-		echo "\t<li><a href=\"{$PHP_SELF}?action=confirm_alter&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['stralter']}</a></li>\n";
+		echo "\t<li><a href=\"tblproperties.php?action=add_column&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['straddcolumn']}</a></li>\n";
+		echo "\t<li><a href=\"tblproperties.php?action=confirm_alter&amp;{$misc->href}&amp;table=", urlencode($_REQUEST['table']),"\">{$lang['stralter']}</a></li>\n";
 		echo "</ul>\n";
 	}
 
